@@ -197,6 +197,11 @@ impl InputHandler {
                 self.os_input
                     .send_to_server(ClientToServerMsg::ColorRegisters(color_registers));
             },
+            AnsiStdinInstruction::SynchronizedOutput(enabled) => {
+                self.send_client_instructions
+                    .send(ClientInstruction::SetSynchronizedOutput(enabled))
+                    .unwrap();
+            },
         }
     }
     fn handle_mouse_event(&mut self, mouse_event: &MouseEvent) {
@@ -283,13 +288,13 @@ impl InputHandler {
             Action::NoOp => {},
             Action::Quit => {
                 self.os_input
-                    .send_to_server(ClientToServerMsg::Action(action, client_id));
+                    .send_to_server(ClientToServerMsg::Action(action, None, client_id));
                 self.exit(ExitReason::Normal);
                 should_break = true;
             },
             Action::Detach => {
                 self.os_input
-                    .send_to_server(ClientToServerMsg::Action(action, client_id));
+                    .send_to_server(ClientToServerMsg::Action(action, None, client_id));
                 self.exit(ExitReason::NormalDetached);
                 should_break = true;
             },
@@ -298,7 +303,7 @@ impl InputHandler {
                 // server later that atomically changes the mode as well
                 self.mode = mode;
                 self.os_input
-                    .send_to_server(ClientToServerMsg::Action(action, None));
+                    .send_to_server(ClientToServerMsg::Action(action, None, None));
             },
             Action::CloseFocus
             | Action::ClearScreen
@@ -318,7 +323,7 @@ impl InputHandler {
             | Action::MoveFocusOrTab(_) => {
                 self.command_is_executing.blocking_input_thread();
                 self.os_input
-                    .send_to_server(ClientToServerMsg::Action(action, client_id));
+                    .send_to_server(ClientToServerMsg::Action(action, None, client_id));
                 self.command_is_executing
                     .wait_until_input_thread_is_unblocked();
             },
@@ -333,7 +338,7 @@ impl InputHandler {
             },
             _ => self
                 .os_input
-                .send_to_server(ClientToServerMsg::Action(action, client_id)),
+                .send_to_server(ClientToServerMsg::Action(action, None, client_id)),
         }
 
         should_break
