@@ -42,6 +42,7 @@ pub struct LayoutApplier<'a> {
     os_api: Box<dyn ServerOsApi>,
     debug: bool,
     arrow_fonts: bool,
+    styled_underlines: bool,
 }
 
 impl<'a> LayoutApplier<'a> {
@@ -63,6 +64,7 @@ impl<'a> LayoutApplier<'a> {
         os_api: &Box<dyn ServerOsApi>,
         debug: bool,
         arrow_fonts: bool,
+        styled_underlines: bool,
     ) -> Self {
         let viewport = viewport.clone();
         let senders = senders.clone();
@@ -93,6 +95,7 @@ impl<'a> LayoutApplier<'a> {
             os_api,
             debug,
             arrow_fonts,
+            styled_underlines,
         }
     }
     pub fn apply_layout(
@@ -260,6 +263,7 @@ impl<'a> LayoutApplier<'a> {
                             layout.run.clone(),
                             self.debug,
                             self.arrow_fonts,
+                            self.styled_underlines,
                         );
                         if let Some(pane_initial_contents) = &layout.pane_initial_contents {
                             new_plugin.handle_pty_bytes(pane_initial_contents.as_bytes().into());
@@ -297,6 +301,7 @@ impl<'a> LayoutApplier<'a> {
                                 layout.run.clone(),
                                 self.debug,
                                 self.arrow_fonts,
+                                self.styled_underlines,
                             );
                             if let Some(pane_initial_contents) = &layout.pane_initial_contents {
                                 new_pane.handle_pty_bytes(pane_initial_contents.as_bytes().into());
@@ -387,6 +392,7 @@ impl<'a> LayoutApplier<'a> {
                     floating_pane_layout.run.clone(),
                     self.debug,
                     self.arrow_fonts,
+                    self.styled_underlines,
                 );
                 if let Some(pane_initial_contents) = &floating_pane_layout.pane_initial_contents {
                     new_pane.handle_pty_bytes(pane_initial_contents.as_bytes().into());
@@ -427,6 +433,7 @@ impl<'a> LayoutApplier<'a> {
                     floating_pane_layout.run.clone(),
                     self.debug,
                     self.arrow_fonts,
+                    self.styled_underlines,
                 );
                 if let Some(pane_initial_contents) = &floating_pane_layout.pane_initial_contents {
                     new_pane.handle_pty_bytes(pane_initial_contents.as_bytes().into());
